==> likewise-open_5.4.0.42111.orig.tar.gz: likewise-open-5.4.0.42111/lwio/server/srv/elements/includes.h <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */



/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        includes.h
 *
 * Abstract:
 *
 *        Likewise IO (LWIO) - SRV
 *
 *        Elements
 *
 * Authors: Sriram Nambakam (snambakam@likewise.com)
 */

#include <config.h>
#include <lwiosys.h>

#include <uuid/uuid.h>

#include <openssl/rand.h>
#include <openssl/hmac.h>

#include <krb5.h>
#include <gssapi/gssapi.h>
#include <gssapi/gssapi_generic.h>
#include <gssapi/gssapi_krb5.h>

#include <lwio/lwio.h>

#include <lwiodef.h>
#include <lwioutils.h>
#include <lwiolog_r.h>

#include <lw/ntstatus.h>

#include <iodriver.h>
#include <ioapi.h>

#include <smbwire.h>
#include <srvecp.h>

#include <shareapi.h>
#include <srvutils.h>
#include <elementsapi.h>

#include "defs.h"
#include "structs.h"
#include "srvtimer.h"

#include "externs.h"

==> likewise-open_6.0.0.53010.orig.tar.gz: likewise-open-6.0.0.53010/lwio/server/srv/elements/includes.h <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 * -*- mode: c, c-basic-offset: 4 -*- */

/*
 * Copyright Likewise Software
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */



/*
 * Copyright (C) Likewise Software. All rights reserved.
 *
 * Module Name:
 *
 *        includes.h
 *
 * Abstract:
 *
 *        Likewise IO (LWIO) - SRV
 *
 *        Elements
 *
 * Authors: Sriram Nambakam (snambakam@likewise.com)
 */

#include <config.h>
#include <lwiosys.h>

#include <uuid/uuid.h>

#include <openssl/rand.h>
#include <openssl/hmac.h>

#include <krb5.h>
#include <gssapi/gssapi.h>
#include <gssapi/gssapi_generic.h>
#include <gssapi/gssapi_krb5.h>

#include <lwio/lwio.h>
#include <lwio/lwiosrvstatprovider.h>
#include <lwio/lmshare.h>

#include <lwiodef.h>
#include <lwioutils.h>
#include <lwiolog_r.h>
#include <srvecp.h>

#include <lw/ntstatus.h>

#include <iodriver.h>
#include <ioapi.h>

#include <smbwire.h>

#include <shareapi.h>
#include <statisticsapi.h>
#include <srvutils.h>
#include <elementsapi.h>

#include "defs.h"
#include "structs.h"
#include "prototypes.h"

#include "externs.h"

VOID
SrvOplockStateRundown(
    PLWIO_SRV_FILE pFile
    );

VOID
SrvOplock2StateRundown(
    PLWIO_SRV_FILE_2 pFile
    );
